location

# XMLRésuméLibrary: User Guide

link | Element Reference | major

## Name

location — A location, with city-level granularity

## Synopsis

### Content Model

    (city?,(state|province|county)?,country?)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `location` element specifies a level location, such as “London, England”, “Seattle, Washington”, “St. Louis, Missouri, USA”, or “Newfoundland, Canada”.

### Parents

`location` may be contained in these elements: `degree`, `job`, `membership`

## See Also

`address`.

## Examples

    <location>
      <city>Los Angeles<city>
      <state>California</state>
      <country>USA</country>
    </location>

    <location>
      <city>Paris<city>
      <country>France</country>
    </location>

link | Element Reference | major